{% load i18n  %}
{% load url from future %}
{% if tags_cloud %}
<h4>{% trans "Tag cloud" %}</h4>
<ul class="nav nav-list">
    {% for tag in tags_cloud %}
        <li><a href="{% url 'planet_by_tag_author_detail' author.id author.get_slug tag.name %}" class="tag level{{ tag.font_size }}">{{ tag|safe }}</a></li>
    {% endfor %}
</ul>
{% endif %}
