{% load i18n %}
{% load url from future %}
<h2>
  <a href="{{ post.url }}" title="{% trans 'Read ' %} {{ post.title|safe }}"
    onclick="javascript: _gaq.push(['_trackEvent', 'Title Link', 'Click', 'long-content']);">
        {{ post.title|striptags|safe }}
  </a>
</h2>
<p class="content">
    <span class="date">{{ post.date_modified|date:"M d Y" }}</span> &square;
    <a href="{{ post.get_absolute_url }}" title="{% trans 'Read an archived version of' %} {{ post.title|safe }}"
      onclick="javascript: _gaq.push(['_trackEvent', 'Archived Version Link', 'Click', 'long-content']);">
      {% trans "[Archived Version]" %}
    </a> &square;
    {% trans "Published at" %} <a href="{{ post.feed.blog.get_absolute_url }}" title="{% trans 'See all posts for this blog' %}">{{ post.feed.blog.title }}</a>
    {% if post.tags.count %} under tags&nbsp;
      {% for tag in post.tags.all|slice:":5" %}
          <span class="label"><a href="{% url 'planet_tag_detail' tag.name %}" title="Tag">{{ tag.name }}</a></span>
      {% endfor %}
    {% endif %}
    <div>
      {{ post.content|safe }}
    </div>
</p>
<br/>
